//
// Informa -- RSS Library for Java
// Copyright (c) 2002 by Niko Schmuck
//
// Niko Schmuck
// http://sourceforge.net/projects/informa
// mailto:niko_schmuck@users.sourceforge.net
//
// This library is free software.
//
// You may redistribute it and/or modify it under the terms of the GNU
// Lesser General Public License as published by the Free Software Foundation.
//
// Version 2.1 of the license should be included with this distribution in
// the file LICENSE. If the license is not included with this distribution,
// you may find a copy at the FSF web site at 'www.gnu.org' or 'www.fsf.org',
// or you may write to the Free Software Foundation, 675 Mass Ave, Cambridge, 
// MA 02139 USA.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied waranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//


// $Id: Category.java,v 1.5 2003/09/28 21:41:57 niko_schmuck Exp $

package de.nava.informa.impl.hibernate;

import java.util.ArrayList;
import java.util.Collection;

import de.nava.informa.core.CategoryIF;

/**
 * Hibernate implementation of the CategoryIF interface.
 * 
 * @author Niko Schmuck (niko@nava.de)
 * 
 * @hibernate.class
 *  table="CATEGORIES" 
 */
public class Category implements CategoryIF, java.io.Serializable {

  private int id;
  private String title;
  private CategoryIF parent;
  private Collection children;

  public Category() {
    this("Unnamed category");
  }

  public Category(String title) {
    setTitle(title);
    this.children = new ArrayList();
  }
  
  // --------------------------------------------------------------
  // implementation of CategoryIF interface
  // --------------------------------------------------------------

  /**
   * @hibernate.id
   *  generator-class="native"
   *  column="CATEGORY_ID"
   *  type="integer"
   */
  public int getIntId() {
    return id;
  }

  public void setIntId(int id) {
    this.id = id;
  }

  public long getId() {
    return id;
  }

  public void setId(long longid) {
    this.id = (int) longid;
  }

  /**
   * @hibernate.property
   *  column="TITLE"
   *  not-null="true"
   */
  public String getTitle() {
    return title;
  }

  public void setTitle(String title) {
    this.title = title;
  }

  /**
   * @hibernate.many-to-one
   *  class="de.nava.informa.impl.hibernate.Category"
   *  column="PARENT_ID" 
   */
  public CategoryIF getParent() {
    return parent;
  }

  public void setParent(CategoryIF parent) {
    this.parent = parent;
  }

  /**
   * @hibernate.bag
   *  lazy="true"
   *  order-by="CATEGORY_ID"
   * @hibernate.collection-key
   *  column="PARENT_ID"
   * @hibernate.collection-one-to-many
   *  class="de.nava.informa.impl.hibernate.Category"
   */
  public Collection getChildren() {
    return children;
  }
  
  public void setChildren(Collection children) {
    this.children = children;
  }
  
  public void addChild(CategoryIF child) {
    children.add(child);
    child.setParent(this);
  }
  
  public void removeChild(CategoryIF child) {
    children.remove(child);
  }
  
  // --------------------------------------------------------------
  // overwrite default method implementation from Object 
  // --------------------------------------------------------------

  public String toString() {
    return "[Category (" + id + "): " + title + "]";
  }
  
}
