//
// Informa -- RSS Library for Java
// Copyright (c) 2002 by Niko Schmuck
//
// Niko Schmuck
// http://sourceforge.net/projects/informa
// mailto:niko_schmuck@users.sourceforge.net
//
// This library is free software.
//
// You may redistribute it and/or modify it under the terms of the GNU
// Lesser General Public License as published by the Free Software Foundation.
//
// Version 2.1 of the license should be included with this distribution in
// the file LICENSE. If the license is not included with this distribution,
// you may find a copy at the FSF web site at 'www.gnu.org' or 'www.fsf.org',
// or you may write to the Free Software Foundation, 675 Mass Ave, Cambridge,
// MA 02139 USA.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied waranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//


// $Id: ItemEnclosure.java,v 1.3 2003/10/15 10:04:18 niko_schmuck Exp $

package de.nava.informa.impl.hibernate;

import java.net.URL;

import de.nava.informa.core.ItemIF;
import de.nava.informa.core.ItemEnclosureIF;

/**
 * Hibernate implementation of the ItemSourceIF interface.
 *
 * @author Michael Harhen
 *
 * @hibernate.class
 *  table="ITEM_ENCLOSURE"
 */
public class ItemEnclosure implements ItemEnclosureIF, java.io.Serializable {

   private int id;
   private ItemIF item;
   private URL location;
   private int length;
   private String type;

   public ItemEnclosure() {
     this(null);
   }

   public ItemEnclosure(ItemIF item) {
     this(item, null, null, -1);
   }

   public ItemEnclosure(ItemIF item, URL location, String type, int length) {
     this.item = item;
     this.location = location;
     this.type = type;
     this.length = length;
   }

  /**
   * @hibernate.id
   *  generator-class="native"
   *  column="ITEM_ENCLOSURE_ID"
   *  type="integer"
   */
  public int getIntId() {
    return id;
  }

  public void setIntId(int id) {
    this.id = id;
  }

  public long getId() {
    return id;
  }

  public void setId(long longid) {
    this.id = (int) longid;
  }

  // --------------------------------------------------------------
  // implementation of ItemEnclosureIF interface
  // --------------------------------------------------------------

  /**
   * @hibernate.many-to-one
   *  column="ITEM_ID"
   *  class="de.nava.informa.impl.hibernate.Item"
   *  not-null="true"
   */
  public ItemIF getItem() {
    return item;
  }

  public void setItem(ItemIF item) {
    this.item = item;
  }

  /**
   * @hibernate.property
   *  column="LOCATION"
   */
  public URL getLocation() {
    return location;
  }

  public void setLocation(URL location) {
    this.location = location;
  }

  /**
   * @hibernate.property
   *  column="TYPE"
   */
  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  /**
   * @hibernate.property
   *  column="LENGTH"
   */
  public int getLength() {
    return length;
  }

  public void setLength(int length) {
    this.length = length;
  }

}
