//
// Informa -- RSS Library for Java
// Copyright (c) 2002 by Niko Schmuck
//
// Niko Schmuck
// http://sourceforge.net/projects/informa
// mailto:niko_schmuck@users.sourceforge.net
//
// This library is free software.
//
// You may redistribute it and/or modify it under the terms of the GNU
// Lesser General Public License as published by the Free Software Foundation.
//
// Version 2.1 of the license should be included with this distribution in
// the file LICENSE. If the license is not included with this distribution,
// you may find a copy at the FSF web site at 'www.gnu.org' or 'www.fsf.org',
// or you may write to the Free Software Foundation, 675 Mass Ave, Cambridge,
// MA 02139 USA.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied waranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//


// $Id: ItemSource.java,v 1.3 2003/10/15 10:04:19 niko_schmuck Exp $

package de.nava.informa.impl.hibernate;

import java.util.Date;
import de.nava.informa.core.ItemIF;
import de.nava.informa.core.ItemSourceIF;

/**
 * Hibernate implementation of the ItemSourceIF interface.
 *
 * @author Michael Harhen
 *
 * @hibernate.class
 *  table="ITEM_SOURCE"
 */
public class ItemSource implements ItemSourceIF, java.io.Serializable {

  private int id;
  private ItemIF item;
  private String name;
  private String location;
  private Date timestamp;

  public ItemSource() {
    this(null);
  }

  /**
   * Default constructor.
   */
  public ItemSource(ItemIF item) {
    this(item, null, null, null);
  }

  public ItemSource(ItemIF item, String name, String location, Date timestamp) {
    this.item = item;
    this.name = name;
    this.location = location;
    this.timestamp = timestamp;
  }

  /**
   * @hibernate.id
   *  generator-class="native"
   *  column="ITEM_SOURCE_ID"
   *  type="integer"
   */
  public int getIntId() {
    return id;
  }

  public void setIntId(int id) {
    this.id = id;
  }

  public long getId() {
    return id;
  }

  public void setId(long longid) {
    this.id = (int) longid;
  }

  // --------------------------------------------------------------
  // implementation of ItemSourceIF interface
  // --------------------------------------------------------------

  /**
   * @hibernate.many-to-one
   *  column="ITEM_ID"
   *  class="de.nava.informa.impl.hibernate.Item"
   *  not-null="true"
   */
  public ItemIF getItem() {
    return item;
  }

  public void setItem(ItemIF item) {
    this.item = item;
  }

  /**
   * @hibernate.property
   *  column="NAME"
   */
  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  /**
   * @hibernate.property
   *  column="LOCATION"
   */
  public String getLocation() {
    return location;
  }

  public void setLocation(String location) {
    this.location = location;
  }

  /**
   * @hibernate.property
   *  column="TIMESTAMP"
   */
  public Date getTimestamp() {
    return timestamp;
  }

  public void setTimestamp(Date timestamp) {
    this.timestamp = timestamp;
  }

}
